@@ -122,6 +122,10 @@ static void       chat_view_copy_address_cb (GtkMenuItem         *menuitem,
 					     const gchar         *url);
 static void       chat_view_realize_cb      (GossipChatView      *widget,
 					     gpointer             data);
+
+static void       chat_view_clear_view_cb   (GtkMenuItem *menuitem,
+					     GossipChatView *view);
+
 static gint       chat_view_url_regex_match (const gchar         *msg,
 					     GArray              *start,
 					     GArray              *end);
@@ -271,6 +275,8 @@ chat_view_setup_tags (GossipChatView *view)
 			  tag);
 }
 
+
+
 static void
 chat_view_populate_popup (GossipChatView *view,
 			  GtkMenu        *menu,
@@ -307,6 +313,18 @@ chat_view_populate_popup (GossipChatView *view,
 						&start, &end, FALSE);
 	}
 
+	item = gtk_menu_item_new ();
+	gtk_menu_shell_prepend (GTK_MENU_SHELL (menu), item);
+	gtk_widget_show (item);
+	
+	item = gtk_menu_item_new_with_mnemonic (_("C_lear"));
+	g_signal_connect (item,
+			  "activate",
+			  G_CALLBACK (chat_view_clear_view_cb),
+			  view);
+	gtk_menu_shell_prepend (GTK_MENU_SHELL (menu), item);
+	gtk_widget_show (item);
+
 	if (!str || strlen (str) == 0) {
 		return;
 	}
@@ -316,10 +334,6 @@ chat_view_populate_popup (GossipChatView *view,
 				"url", str, 
 				(GDestroyNotify) g_free);
 
-	item = gtk_menu_item_new ();
-	gtk_menu_shell_prepend (GTK_MENU_SHELL (menu), item);
-	gtk_widget_show (item);
-	
 	item = gtk_menu_item_new_with_mnemonic (_("_Copy Link Address"));
 	g_signal_connect (item,
 			  "activate",
@@ -423,8 +437,11 @@ chat_view_open_address (const gchar *url)
 	if (!url || strlen (url) == 0) {
 		return;
 	}
-	
-	if (strncmp (url, "http://", 7)) {
+
+	/* gnome_url_show doesn't work when there's no protocol, so we might
+	 * need to add one.
+	 */
+	if (strstr (url, "://") == NULL) {
 		gchar *tmp;
 		
 		tmp = g_strconcat ("http://", url, NULL);
@@ -468,6 +485,12 @@ chat_view_realize_cb (GossipChatView *view, gpointer data)
 	gdk_window_set_background (win, &GTK_WIDGET(view)->style->base[GTK_STATE_NORMAL]);
 }
 
+static void
+chat_view_clear_view_cb (GtkMenuItem *menuitem, GossipChatView *view)
+{
+	gossip_chat_view_clear (view);
+}
+
 static gint
 chat_view_url_regex_match (const gchar *msg,
 			   GArray      *start,
@@ -489,17 +512,15 @@ chat_view_url_regex_match (const gchar *msg,
 		ret = regexec (&dingus, msg + offset, 1, matches, 0);
 
 		if (ret == 0) {
-			gint s, e;
+			gint s;
 			
 			num_matches++;
 
 			s = matches[0].rm_so + offset;
-			e = matches[0].rm_eo + offset;
+			offset = matches[0].rm_eo + offset;
 			
 			g_array_append_val (start, s);
-			g_array_append_val (end, e);
-
-			offset += e;
+			g_array_append_val (end, offset);
 		}
 	}
 		
@@ -688,6 +709,31 @@ gossip_chat_view_new (void)
 	return g_object_new (GOSSIP_TYPE_CHAT_VIEW, NULL);
 }
 
+static gboolean
+chat_view_is_scrolled_down (GossipChatView *view)
+{
+	GtkWidget *sw;
+
+	/* Turn off for version before 2.2.3. */
+	if (GTK_MAJOR_VERSION == 2 && GTK_MINOR_VERSION == 2 &&
+	    GTK_MAJOR_VERSION < 3) {
+		return TRUE;
+	}
+	
+	sw = gtk_widget_get_parent (GTK_WIDGET (view));
+	if (GTK_IS_SCROLLED_WINDOW (sw)) {
+		GtkAdjustment *vadj;
+		
+		vadj = gtk_scrolled_window_get_vadjustment (GTK_SCROLLED_WINDOW (sw));
+
+		if (vadj->value + vadj->page_size / 2 < vadj->upper - vadj->page_size) {
+			return FALSE;
+		}
+	}
+
+	return TRUE;
+}
+
 void
 gossip_chat_view_append_chat_message (GossipChatView *view,
 				      const gchar    *time_str,
@@ -701,8 +747,7 @@ gossip_chat_view_append_chat_message (GossipChatView *view,
 	GtkTextMark   *mark;
 	gint           num_matches, i;
 	GArray        *start, *end;
-	gboolean       bottom = TRUE;
-	GtkWidget     *sw;
+	gboolean       bottom;
 
 	if (msg == NULL || msg[0] == 0) {
 		return;
@@ -711,19 +756,8 @@ gossip_chat_view_append_chat_message (GossipChatView *view,
 	chat_view_maybe_append_datestamp (view);
 	chat_view_maybe_append_timestamp (view, time_str);
 	
-	sw = gtk_widget_get_parent (GTK_WIDGET (view));
-	if (GTK_IS_SCROLLED_WINDOW (sw)) {
-		GtkAdjustment *vadj;
+	bottom = chat_view_is_scrolled_down (view);
 
-		vadj = gtk_scrolled_window_get_vadjustment (GTK_SCROLLED_WINDOW (sw));
-
-		if (vadj->value < vadj->upper - vadj->page_size) {
-			bottom = FALSE;
-		}
-	}
-	
-	/* Turn off this for now since it doesn't work. */
-	bottom = TRUE;
 	buffer = gtk_text_view_get_buffer (GTK_TEXT_VIEW (view));
 
 	if (from) {
@@ -733,10 +767,10 @@ gossip_chat_view_append_chat_message (GossipChatView *view,
 			gtk_text_buffer_get_end_iter (buffer, &iter);
 
 			/* FIXME: This only works if nick == name... */
-			if (!strcmp (from, to)) {
+			if (to && strcmp (from, to) == 0) {
 				nick_tag = "nick-me";
 			}
-			else if (strstr (msg, to)) {
+			else if (to && strstr (msg, to)) {
 				nick_tag = "nick-highlight";
 			} else {
 				nick_tag = "nick-other";
@@ -807,7 +841,7 @@ gossip_chat_view_append_chat_message (GossipChatView *view,
 			s = g_array_index (start, gint, i);
 			e = g_array_index (end, gint, i);
 
-			if (s > last + 1) {
+			if (s > last) {
 				tmp = gossip_utils_substring (msg, last, s);
 
 				gtk_text_buffer_get_end_iter (buffer, &iter);
@@ -880,6 +914,9 @@ gossip_chat_view_append_event_msg (GossipChatView *view,
 	gchar         *stamp;
 	gchar         *msg;
 	GtkTextMark   *mark;
+	gboolean       bottom;
+
+	bottom = chat_view_is_scrolled_down (view);
 
 	buffer = gtk_text_view_get_buffer (GTK_TEXT_VIEW (view));
 	gtk_text_buffer_get_end_iter (buffer, &iter);
@@ -910,18 +947,20 @@ gossip_chat_view_append_event_msg (GossipChatView *view,
 				"\n",
 				1);
 
-	gtk_text_buffer_get_end_iter (buffer, &iter);
-	mark = gtk_text_buffer_create_mark (buffer,
-					    NULL,
-					    &iter,
-					    FALSE);
+	if (bottom) {
+		gtk_text_buffer_get_end_iter (buffer, &iter);
+		mark = gtk_text_buffer_create_mark (buffer,
+						    NULL,
+						    &iter,
+						    FALSE);
 		
-	gtk_text_view_scroll_to_mark (GTK_TEXT_VIEW (view),
-				      mark,
-				      0.0,
-				      FALSE,
-				      0,
-				      0);
+		gtk_text_view_scroll_to_mark (GTK_TEXT_VIEW (view),
+					      mark,
+					      0.0,
+					      FALSE,
+					      0,
+					      0);
+	}
 }
 
 void
@@ -941,6 +980,17 @@ gossip_chat_view_set_margin (GossipChatView *view, gint margin)
 			  NULL);
 }
 
+void
+gossip_chat_view_clear (GossipChatView *view)
+{
+	GtkTextBuffer *buffer;
+
+	g_return_if_fail (GOSSIP_IS_CHAT_VIEW (view));
+	
+	buffer = gtk_text_view_get_buffer (GTK_TEXT_VIEW (view));
+	gtk_text_buffer_set_text (buffer, "", -1);
+}
+
 
 
 
